### Adding more checks
Glad to see that you have an exciting check to implement or
Your work requires a different check which is not part of this repo

**Steps**
1. git [clone](https://github.com/moengage/alice.git) alice
2. open checker_imply.py
3. just add your checker definition here in this file & in your config file
4. [re-run](README.md) the project

**Need**
- coding knowledge of [python](https://www.python.org/)
- install dependencies from requires.txt